@@ -18,7 +18,7 @@ Usage::
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
     ```
 """
-from typing import Generic, Iterator, List, TypeVar
+from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -41,18 +41,18 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
     """
 
     def paginate(
         self,
         *,
-        Filters: List["FilterTypeDef"] = None,
+        Filters: Sequence["FilterTypeDef"] = None,
         SortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.44/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
